@@ -1,16 +1,18 @@
 ( cd sbin ; rm -rf mount.smbfs )
 ( cd sbin ; ln -sf /usr/bin/smbmount mount.smbfs )
-#%% begin initialize samba-3.0.30-i586-P1
+#%% begin initialize samba-3.0.37-i586-P1
 chk=`grep swat /etc/services`
-if [ "$chk.x" == ".x" ]; then
+if [ "$chk.x" = ".x" ]; then
   echo 'swat		901/tcp' >> /etc/services
 fi
 
 chk=`grep swat /etc/inetd.conf`
-if [ "$chk.x" == ".x" ]; then
+if [ "$chk.x" = ".x" ]; then
   echo 'swat	stream tcp nowait root /usr/sbin/tcpd /usr/sbin/swat' >> /etc/inetd.conf
+  chk=`ps ax | grep inetd | grep -v grep | gawk '{print $1}'`
+  if [ "$chk.x" != ".x" ]; then
+    kill -HUP $chk
+  fi
 fi
 
-killall -HUP inetd
-
 #%% end
